<?php
error_reporting(0);
session_start();
// Generate a hash with sha256 encryption based on the current time to make unique.
function hashing() {
    if ($date = new DateTime()) {
        return hash('sha256', $date->getTimestamp());
    } else {
        return false;
    }
}

function validateUSGN() {
    $accessKey = null;
    $usgn = null;
    // UnrealSoftware Connect
    $api = "https://unrealsoftware.de/connect.php";
    $redirectURI = "OWNWEBSITE";
 
    if($_SERVER['REQUEST_METHOD'] == 'POST') {
        if (!is_numeric($_POST['usgn']) || $_POST['usgn']<1 || $_POST['usgn']>999999) {
            // if usgn is not numeric and/or below 1 or more than 9999999
            echo "Invalid USGN ID format: Must be numeric and above 0!<br>";
        } else {
            $accessKey = hashing(); // Generate an access key

            // Connect with API
            $setkey = $api .= "?setkey=" . $accessKey . "&autoclose=1&redirect=" . $redirectURI;
            header("Location:" . $setkey);

            // Store data in brower cookies, for now...
            setcookie("accessKey", $accessKey, time() + (86400 * 30), "/"); // 86400 = 1 day
            setcookie("usgn", $_POST['usgn'], time() + (86400 * 30), "/"); // 86400 = 1 day
           
        }

    }
}


function getName() {
    $name = file_get_contents("https://unrealsoftware.de/connect.php?getname=" . $_COOKIE['usgn']);

    if (isset($_COOKIE['usgn'])) {
        return $name;
    } else {
        return false;
    }
}

function getUSGN() {
    $usgn = file_get_contents("https://unrealsoftware.de/connect.php?getid=" . $_COOKIE['usgn']);
    if (isset($_COOKIE['usgn'])) {
        return $_COOKIE['usgn'];
    } else {
        return "ERROR";
    }
}

function isLoggedIn() {
    $check = file_get_contents("https://unrealsoftware.de/connect.php?keyofid=" . $_COOKIE['usgn'] . "&iskey=" . $_COOKIE['accessKey']);
    if ($check == 1 and isset($_COOKIE['accessKey']))  {
        return true;
    } elseif ($check == 0) {
        return false;
    } else {
        return false;
    }
}

function getCountryName () {
  
$country_name = json_decode(file_get_contents("http://country.io/names.json"), true);
    $data = getData("country");
    return $country_name[strtoupper($data)];
}

function getData ($data) {

        if ($data == "avatar") {
        $avatar = file_get_contents("https://unrealsoftware.de/getuserdata.php?id=" . $_COOKIE['usgn'] . "&data=avatar");
        echo "<img src='https://unrealsoftware.de/" . $avatar . "' alt='Avatar' class=' rounded-full'/>";

        } elseif ($data == "mode") {
            $mode = file_get_contents("https://unrealsoftware.de/getuserdata.php?id=" . $_COOKIE['usgn'] . "&data=modetxt");
            $pt_status = preg_replace('#(<[a-z ]*)(style=("|\')(.*?)("|\'))([a-z ]*>)#', '\\1\\6', $mode);
            return $pt_status;

        } elseif ($data == "country") {
            $country = file_get_contents("https://unrealsoftware.de/getuserdata.php?id=" . $_COOKIE['usgn'] . "&data=country");
            return $country;

        } elseif ($data == "regdate") {
            $regdate = file_get_contents("https://unrealsoftware.de/getuserdata.php?id=" . $_COOKIE['usgn'] . "&data=regdate");
            $format_regdate = date("Y-m-d", $regdate);
            return $format_regdate;
            
        } else {
            return false;
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <script src="https://cdn.tailwindcss.com"></script>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">

    <title>USGN Connect</title>
</head>

    <body class="bg-gray-100">
<?php if (isLoggedIn()) { ?> 

    <div class="flex flex-col-reverse justify-center bg-white mx-96 items-center my-20 py-40 shadow-sm relative">

        <div class="flex flex-row-reverse absolute top-0 right-0 p-6 text-right items-center">
            <div class="ml-4"><?php echo getData("avatar"); ?></div>
                <div class="flex flex-col ml-4">
                <span><?php echo getName(); ?></span>
                <span><?php echo getData("mode"); ?></span>
                <span>Country: <?php echo getCountryName (); ?> <img class="inline-flex" src="https://flagcdn.com/24x18/<?php echo getData("country");?>.png"/></span>
                <span> Registration Date: <?php echo getData("regdate"); ?></p>

            </div>
        </div>
       
        <div class="">
            Some data...
            <a href="logout.php">Logout</a>
        </div>
    </div>
  
<?php
} else { 
?>

    <div class="flex flex-col justify-center bg-white mx-96 items-center my-20 py-40 shadow-sm">

    <div class="h-full flex flex-col items-center space-y-4">
        
    <img src="https://unrealsoftware.de/img/pub/unrealsoftware.png">
    <p class="text-green-500">Enter your USGN ID to get ConnectED</p>
    </div>

    <form action="<?=$_SERVER['PHP_SELF'];?>" method="POST" class="py-8" >
        <div class="flex flex-row items-center relative">
            <div class="flex relative items-center">
                <span class="absolute inset-y-0 left-0 flex items-center  bg-green-100 text-sm border-t border-b border-l border-green-500 px-2"><img src="https://unrealsoftware.de/img/pub/unrealsoftware_icon.gif"></span>
                <input type="text" class="focus:outline-none py-1 border border-green-500 w-full pl-10" name="usgn" /><br>
            
            </div>
            <p class="absolute inset-y-0 top-10 text-xs text-red-500"><?php validateUSGN();?></p>
            <button type="submit" class="bg-green-500 px-4 text-gray-50 py-1 border border-green-500 focus:outline-none hover:bg-green-400">Connect</button>
        </div> 
    </form>
    </div>

<?php
}
?>

</body>
</html>